<?php
/**
 * retbo functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package retbo
 */

if ( !function_exists('retbo_setup') ) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function retbo_setup()
    {
        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on retbo, use a find and replace
         * to change 'retbo' to the name of your theme in all the template files.
         */
        load_theme_textdomain('retbo', get_template_directory() . '/languages');

        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support('title-tag');

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support('post-thumbnails');

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(array(
            'main-menu' => esc_html__('Main Menu', 'retbo'),
            'top-menu' => esc_html__('Top Menu', 'retbo')
        ));

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ));

        // Set up the WordPress core custom background feature.
        add_theme_support('custom-background', apply_filters('retbo_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        )));

        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');

        //Enable custom header
        add_theme_support('custom-header');


        // enable woocommerce
        add_theme_support( 'woocommerce');
        // add_theme_support( 'wc-product-gallery-zoom' );
        add_theme_support( 'wc-product-gallery-lightbox' );
        add_theme_support( 'wc-product-gallery-slider' );


        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support('custom-logo', array(
            'height' => 250,
            'width' => 250,
            'flex-width' => true,
            'flex-height' => true,
        ));

        /**
         * Enable suporrt for Post Formats
         *
         * see: https://codex.wordpress.org/Post_Formats
         */
        add_theme_support('post-formats', array(
            'image',
            'audio',
            'video',
            'gallery',
            'quote',
        ));

        // Add theme support for selective refresh for widgets.
        //add_theme_support( 'customize-selective-refresh-widgets' );

        // Add support for Block Styles.
        add_theme_support('wp-block-styles');

        // Add support for full and wide align images.
        add_theme_support('align-wide');

        // Add support for editor styles.
        add_theme_support('editor-styles');

        // Add support for responsive embedded content.
        add_theme_support('responsive-embeds');

        remove_theme_support( 'widgets-block-editor' );


        add_image_size('retbo-case-details', 1170, 600, array('center', 'center'));
        add_image_size('retbo-post-thumb', 500, 350, array('center', 'center'));
        add_image_size('retbo-case-thumb', 700, 544, array('center', 'center'));
        add_image_size('retbo-product-v', 290, 210, array('center', 'top'));
        add_image_size('retbo-product-h', 290, 400, array('center', 'top'));
        add_image_size('retbo-case-vl', 256, 316, array('center', 'top'));
    }
endif;
add_action('after_setup_theme', 'retbo_setup');


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function retbo_content_width()
{
    // This variable is intended to be overruled from themes.
    // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
    // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
    $GLOBALS['content_width'] = apply_filters('retbo_content_width', 640);
}

add_action('after_setup_theme', 'retbo_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function retbo_widgets_init()
{

    $footer_style_2_switch = get_theme_mod('footer_style_2_switch', true);
    $footer_style_3_switch = get_theme_mod('footer_style_3_switch', true);
    $footer_style_4_switch = get_theme_mod('footer_style_4_switch', true);
    $footer_style_5_switch = get_theme_mod('footer_style_5_switch', true);

    /**
     * blog sidebar
     */
    register_sidebar(array(
        'name' => esc_html__('Sidebar', 'retbo'),
        'id' => 'blog-sidebar',
        'before_widget' => '<div id="%1$s" class="widget mb-40 %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',

    ));

    register_sidebar(array(
        'name' => esc_html__('Product Sidebar', 'retbo'),
        'id' => 'product-sidebar',
        'before_widget' => '<div id="%1$s" class="product-widgets side-cat %2$s mb-45">',
        'after_widget' => '</div>',
        'before_title' => '<h6 class="cat-title pb-20">',
        'after_title' => '</h6>',

    ));

    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        register_sidebar(array(
            'name' => esc_html__('Footer ' . $num, 'retbo'),
            'id' => 'footer-' . $num,
            'description' => esc_html__('Footer ' . $num, 'retbo'),
            'before_widget' => '<div id="%1$s" class="footer-widget mb-30 %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h5>',
            'after_title' => '</h5>',
        ));
    }


    // footer 2

    if ($footer_style_2_switch) {
        for ($num = 1; $num <= $footer_widgets; $num++) {
            register_sidebar(array(
                'name' => esc_html__('Footer Style 2: ' . $num, 'retbo'),
                'id' => 'footer-2-' . $num,
                'description' => esc_html__('Footer Style 2: ' . $num, 'retbo'),
                'before_widget' => '<div id="%1$s" class="footer-widget mb-30 %2$s">',
                'after_widget' => '</div>',
                'before_title' => '<h5>',
                'after_title' => '</h5>',
            ));
        }
    }

    // footer 3
    if ($footer_style_3_switch) {
        for ($num = 1; $num <= $footer_widgets; $num++) {
            register_sidebar(array(
                'name' => esc_html__('Footer Style 3: ' . $num, 'retbo'),
                'id' => 'footer-3-' . $num,
                'description' => esc_html__('Footer Style 3: ' . $num, 'retbo'),
                'before_widget' => '<div id="%1$s" class="footer-widget widget-three mb-30 %2$s">',
                'after_widget' => '</div>',
                'before_title' => '<h5>',
                'after_title' => '</h5>',
            ));
        }
    }

    if (!empty($footer_style_4_switch) == true) {
        $footer_widgets = get_theme_mod('footer_widget_number', 5);
        // footer 4
        if ($footer_style_4_switch) {
            for ($num = 1; $num <= $footer_widgets; $num++) {
                register_sidebar(array(
                    'name' => esc_html__('Footer Style 4: ' . $num, 'retbo'),
                    'id' => 'footer-4-' . $num,
                    'description' => esc_html__('Footer Style 4: ' . $num, 'retbo'),
                    'before_widget' => '<div id="%1$s" class="footer-widget footer-widget-four mb-30 %2$s">',
                    'after_widget' => '</div>',
                    'before_title' => '<h5>',
                    'after_title' => '</h5>',
                ));
            }
        }
    }

    register_sidebar(array(
        'name' => esc_html__('Footer Style 5: 1', 'retbo'),
        'id' => 'footer-5-1',
        'description' => esc_html__('Footer Style 5: 1', 'retbo'),
        'before_widget' => '<div id="%1$s" class="footer-widget-five mb-30 %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5>',
        'after_title' => '</h5>',
    ));

    register_sidebar(array(
        'name' => esc_html__('Footer Style 5: 2', 'retbo'),
        'id' => 'footer-5-2',
        'description' => esc_html__('Footer Style 5: 2', 'retbo'),
        'before_widget' => '<div id="%1$s" class="widget-five-common mb-30 %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h6>',
        'after_title' => '</h6>',
    ));

    register_sidebar(array(
        'name' => esc_html__('Footer Style 5: 3', 'retbo'),
        'id' => 'footer-5-3',
        'description' => esc_html__('Footer Style 5: 3', 'retbo'),
        'before_widget' => '<div id="%1$s" class="widget-five-common mb-30 %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h6>',
        'after_title' => '</h6>',
    ));

    register_sidebar(array(
        'name' => esc_html__('Footer Style 5: 4', 'retbo'),
        'id' => 'footer-5-4',
        'description' => esc_html__('Footer Style 5: 4', 'retbo'),
        'before_widget' => '<div id="%1$s" class="footer-widget-five mb-30 %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5>',
        'after_title' => '</h5>',
    ));

}

add_action('widgets_init', 'retbo_widgets_init');

/**
 * Enqueue scripts and styles.
 */

define('RETBO_THEME_DIR', get_template_directory());
define('RETBO_THEME_URI', get_template_directory_uri());
define('RETBO_THEME_CSS_DIR', RETBO_THEME_URI . '/assets/css/');
define('RETBO_THEME_JS_DIR', RETBO_THEME_URI . '/assets/js/');
define('RETBO_THEME_INC', RETBO_THEME_DIR . '/inc/');

/**
 * retbo_scripts description
 * @return [type] [description]
 */
function retbo_scripts()
{
    /**
     * all css files
     */
    wp_enqueue_style('retbo-fonts', retbo_fonts_url(), array(), '1.0.1');
    wp_enqueue_style('pristina', RETBO_THEME_CSS_DIR . 'pristina.font.css', array());
    wp_enqueue_style('bootstrap', RETBO_THEME_CSS_DIR . 'bootstrap.min.css', array());
    wp_enqueue_style('animate', RETBO_THEME_CSS_DIR . 'animate.min.css', array());
    wp_enqueue_style('fontawesome-font', RETBO_THEME_CSS_DIR . 'fontawesome-all.min.css', array());
    wp_enqueue_style('metisMenu', RETBO_THEME_CSS_DIR . 'metisMenu.css', array());
    wp_enqueue_style('nice-select', RETBO_THEME_CSS_DIR . 'nice-select.css', array());
    wp_enqueue_style('magnific-popup', RETBO_THEME_CSS_DIR . 'magnific-popup.css', array());
    wp_enqueue_style('YTPlayer', RETBO_THEME_CSS_DIR . 'jquery.mb.YTPlayer.min.css', array());
    wp_enqueue_style('slick', RETBO_THEME_CSS_DIR . 'slick.css', array());
    wp_enqueue_style('ui-range-slider', RETBO_THEME_CSS_DIR . 'ui-range-slider.css', array());
    wp_enqueue_style('retbo-default', RETBO_THEME_CSS_DIR . 'retbo-default.css', array());
    wp_enqueue_style('retbo-core', RETBO_THEME_CSS_DIR . 'retbo-core.css', array());
    wp_enqueue_style('retbo-unit', RETBO_THEME_CSS_DIR . 'retbo-unit.css', array());
    wp_enqueue_style('retbo-style', get_stylesheet_uri());
    wp_enqueue_style('retbo-responsive', RETBO_THEME_CSS_DIR . 'responsive.css', array());

    if (rtl_enable()) {
        wp_enqueue_style('retbo-rtl', RETBO_THEME_CSS_DIR . 'rtl.css', array());
        wp_enqueue_style('retbo-responsive-rtl', RETBO_THEME_CSS_DIR . 'responsive-rtl.css', array());
    }

    // all js
    wp_enqueue_script('popper', RETBO_THEME_JS_DIR . 'popper.min.js', array('jquery', 'imagesloaded'), '', true);
    wp_enqueue_script('bootstrap', RETBO_THEME_JS_DIR . 'bootstrap.min.js', array('jquery'), '', true);
    wp_enqueue_script('jquery-countdown', RETBO_THEME_JS_DIR . 'jquery.countdown.min.js', array('jquery'), false, true);
    wp_enqueue_script('slick', RETBO_THEME_JS_DIR . 'slick.min.js', array('jquery'), false, true);
    wp_enqueue_script('jquery-ui-slider-range', RETBO_THEME_JS_DIR . 'jquery-ui-slider-range.js', array('jquery'), false, true);
    wp_enqueue_script('jquery-nice-select', RETBO_THEME_JS_DIR . 'jquery.nice-select.min.js', array('jquery'), false, true);
    wp_enqueue_script('isotope-pkgd', RETBO_THEME_JS_DIR . 'isotope.pkgd.min.js', array('jquery'), false, true);
    wp_enqueue_script('metisMenu', RETBO_THEME_JS_DIR . 'metisMenu.min.js', array('jquery'), false, true);
    wp_enqueue_script('jquery-magnific-popup', RETBO_THEME_JS_DIR . 'jquery.magnific-popup.min.js', array('jquery'), false, true);
    wp_enqueue_script('jquery-scrollup', RETBO_THEME_JS_DIR . 'jquery.scrollUp.min.js', array('jquery'), false, true);
    wp_enqueue_script('jquery-YTPlayer', RETBO_THEME_JS_DIR . 'jquery.mb.YTPlayer.min.js', array('jquery'), false, true);
    wp_enqueue_script('wow', RETBO_THEME_JS_DIR . 'wow.min.js', array('jquery'), false, true);

    if (rtl_enable()) {
        wp_enqueue_script('retbo-rtl-main', RETBO_THEME_JS_DIR . 'rtl-main.js', array('jquery'), false, true);
    } else {
        wp_enqueue_script('retbo-main', RETBO_THEME_JS_DIR . 'main.js', array('jquery'), false, true);
    }

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }

}

add_action('wp_enqueue_scripts', 'retbo_scripts');

/*
Register Fonts
*/

function retbo_fonts_url()
{
    $retbo_fonts_url = get_theme_mod('retbo_fonts_url', "family=Muli:ital,wght@0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap");
    $retbo_fonts_url_rtl = get_theme_mod('retbo_fonts_url_rtl', "family=Muli:ital,wght@0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap");
    $font_url = '';

    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    $my_current_lang = apply_filters('wpml_current_language', null);
    $rtl_enable = get_theme_mod('rtl_switch', false);

    if ($my_current_lang != 'en' && $rtl_enable && 'off' !== _x('on', 'Google font: on or off', 'retbo')) {
        $font_url = "//fonts.googleapis.com/css2?" . urlencode($retbo_fonts_url_rtl);
    } elseif ('off' !== _x('on', 'Google font: on or off', 'retbo')) {
        $font_url = "//fonts.googleapis.com/css2?" . urlencode($retbo_fonts_url);
    }

    return $font_url;
}


// wp_body_open
if (!function_exists('wp_body_open')) {
    function wp_body_open()
    {
        do_action('wp_body_open');
    }
}


/**
 * Implement the Custom Header feature.
 */
require RETBO_THEME_INC . 'custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require RETBO_THEME_INC . 'template-functions.php';

/**
 * Custom template helper function for this theme.
 */
require RETBO_THEME_INC . 'template-helper.php';

if (!defined('RETBO_WOOCOMMERCE_ACTIVED')) {
    define('RETBO_WOOCOMMERCE_ACTIVED', in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))));
}

define('RETBO_WISHLIST_ACTIVED', in_array('yith-woocommerce-wishlist/init.php', apply_filters('active_plugins', get_option('active_plugins'))));

define('RETBO_COMPARE_ACTIVED', in_array('yith-woocommerce-compare/init.php', apply_filters('active_plugins', get_option('active_plugins'))));

define('RETBO_QUICK_VIEW_ACTIVED', in_array('yith-woocommerce-quick-view/init.php', apply_filters('active_plugins', get_option('active_plugins'))));

if (RETBO_WOOCOMMERCE_ACTIVED) {
    require_once RETBO_THEME_INC . 'retbo-woocommerce.php';
}


/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
    require RETBO_THEME_INC . 'jetpack.php';
}

/**
 * include retbo functions file
 */
require_once RETBO_THEME_INC . 'class-breadcrumb.php';
require_once RETBO_THEME_INC . 'class-navwalker.php';
// require_once RETBO_THEME_INC . 'class-customizer.php';
// require_once RETBO_THEME_INC . 'customizer_data.php';
require_once RETBO_THEME_INC . 'class-tgm-plugin-activation.php';
require_once RETBO_THEME_INC . 'add_plugin.php';


/**
 * initialize kirki customizer class.
 */
include_once RETBO_THEME_INC . 'kirki-customizer.php';
include_once RETBO_THEME_INC . 'class-retbo-kirki.php';

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function retbo_pingback_header()
{
    if (is_singular() && pings_open()) {
        printf('<link rel="pingback" href="%s">', esc_url(get_bloginfo('pingback_url')));
    }
}

add_action('wp_head', 'retbo_pingback_header');


/**
 *
 * comment section
 *
 */
add_filter('comment_form_default_fields', 'retbo_comment_form_default_fields_func');

function retbo_comment_form_default_fields_func($default)
{
    $default['author'] = '<div class="row">
    <div class="col-xl-6">
    	<div class="contacts-name">
    		<label>' . esc_html__('Your name *', 'retbo') . '</label>
        	<input type="text" name="author">
        </div>
    </div>';
    $default['email'] = '<div class="col-xl-6">
		<div class="contacts-email ">
		<label>' . esc_html__('Your email *', 'retbo') . '</label>
        <input type="text" name="email">
    	</div>
    </div>';
    $default['url'] = '';

    $default['clients_commnet'] = '<div class="col-xl-12">
	<div class="contacts-message">
	<label>' . esc_html__('Comments *', 'retbo') . '</label>
     <textarea id="comment" name="comment" cols="30" rows="10"></textarea>
    </div>';
    return $default;
}

add_filter('comment_form_defaults', 'retbo_comment_form_defaults_func');

function retbo_comment_form_defaults_func($info)
{
    if (!is_user_logged_in()) {
        $info['comment_field'] = '';
        $info['submit_field'] = '%1$s %2$s</div></div>';
    } else {
        $info['comment_field'] = '<div class="comments-textarea contacts-message contact-icon">
        <textarea id="comment" name="comment" cols="30" rows="10"></textarea>';
        $info['submit_field'] = '%1$s %2$s</div>';
    }


    $info['submit_button'] = '<button class="site-btn form-btn" type="submit">' . esc_html__('Post Comment', 'retbo') . ' </button>';

    $info['title_reply_before'] = '<div class="post-comments-title">
                                        <h2>';
    $info['title_reply_after'] = '</h2></div>';
    $info['comment_notes_before'] = '';

    return $info;
}

if (!function_exists('retbo_comment')) {
    function retbo_comment($comment, $args, $depth)
    {
        $GLOBAL['comment'] = $comment;
        extract($args, EXTR_SKIP);
        $args['reply_text'] = '<i class="fas fa-reply-all"></i> Reply';
        $replayClass = 'comment-depth-' . esc_attr($depth);
        ?>
    <li id="comment-<?php comment_ID(); ?>">
        <div class="comments-box">
            <div class="comments-avatar">
                <?php print get_avatar($comment, 102, null, null, array('class' => array())); ?>
            </div>
            <div class="comments-text">
                <div class="avatar-name">
                    <h5><?php print get_comment_author_link(); ?></h5>
                    <span><?php comment_time(get_option('date_format')); ?></span>
                </div>
                <?php comment_text(); ?>
                <?php comment_reply_link(array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
            </div>
        </div>
        <?php
    }
}


/**
 * shortcode supports for removing extra p, spance etc
 *
 */
add_filter('the_content', 'retbo_shortcode_extra_content_remove');
/**
 * Filters the content to remove any extra paragraph or break tags
 * caused by shortcodes.
 *
 * @param string $content String of HTML content.
 * @return string $content Amended string of HTML content.
 * @since 1.0.0
 *
 */
function retbo_shortcode_extra_content_remove($content)
{

    $array = array(
        '<p>[' => '[',
        ']</p>' => ']',
        ']<br />' => ']'
    );
    return strtr($content, $array);

}


// retbo_search_filter_form
if (!function_exists('retbo_search_filter_form')) {
    function retbo_search_filter_form($form)
    {

        $form = sprintf(
            '<div class="sidebar-form"><form class="sidebar-search-form" action="%s" method="get">
      	<input type="text" value="%s" required name="s" placeholder="%s">
      	<button type="submit"> <i class="fas fa-search"></i>  </button>
		</form></div>',
            esc_url(home_url('/')),
            esc_attr(get_search_query()),
            esc_html__('Search', 'retbo')
        );

        return $form;
    }

    add_filter('get_search_form', 'retbo_search_filter_form');
}

add_action('admin_enqueue_scripts', 'retbo_admin_custom_scripts');

function retbo_admin_custom_scripts()
{
    wp_enqueue_media();
    wp_register_script('retbo-admin-custom', get_template_directory_uri() . '/inc/js/admin_custom.js', array('jquery'), '', true);
    wp_enqueue_script('retbo-admin-custom');
}

/**
 * Filter WooCommerce  Search Field
 *
 */
function retbo_custom_product_searchform($form)
{
    $form = '<form role="search" class="sidebar-search-form" method="get" id="searchform" action="' . esc_url(home_url('/')) . '">
        <label class="screen-reader-text" for="s">' . esc_html__('Search for:', 'retbo') . '</label>
        <input type="text" value="' . get_search_query() . '" name="s" id="s" placeholder="' . esc_attr__('Search products...', 'retbo') . '" />   
        <button type="submit" id="searchsubmit"><i class="fas fa-search"></i></button>                          
        <input type="hidden" name="post_type" value="product" />
    </form>';
    return $form;
}

add_filter('get_product_search_form', 'retbo_custom_product_searchform');


// enable_rtl
function retbo_enable_rtl()
{
    if (get_theme_mod('rtl_switch', false)) {
        return ' dir="rtl" ';
    } else {
        return '';
    }
}

function the_dramatist_price_show() {
    global $product;
    if( $product->is_on_sale() ) {
        return $product->get_sale_price();
    }
    return $product->get_regular_price();
}

add_filter( 'woocommerce_get_image_size_gallery_thumbnail', function( $size ) {
    return array(
        'width' => 200,
        'height' => 200,
        'crop' => 0,
    );
} );
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1717562908446';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        