<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package retbo
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function retbo_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}
	return $classes;
}

add_filter( 'body_class', 'retbo_body_classes' );

/**
 * Get tags.
 */
function retbo_get_tag() {
	$html = '';
	if(has_tag()) {
		$html .= '<div class="blog-post-tag"><span>'. esc_html__('Post Tags','retbo') .'</span>';
			$html .= get_the_tag_list('',' ','');
		$html .= '</div>';
	}
	return $html;
}


/**
 * Get categories.
 */
function retbo_get_category() {

$categories = get_the_category( get_the_ID() );
	$x = 0;
	foreach ($categories as $category){
		
	if($x==2){
		break;
	}	
	$x++;
	print '<a class="news-tag" href="' . get_category_link($category->term_id) . '">'  . $category->cat_name . '</a>';

	}
}


/** img alt-text **/
function retbo_img_alt_text( $img_er_id = null ){
	$image_id = $img_er_id;
	$image_alt = get_post_meta($image_id, '_wp_attachment_image_alt', false);
	$image_title = get_the_title($image_id);

	if( !empty($image_id) ){
		if($image_alt){
			$alt_text = get_post_meta($image_id, '_wp_attachment_image_alt', false);
		}else{
			$alt_text = get_the_title($image_id);
		}	
	}else{
		$alt_text = esc_html__('Image Alt Text', 'retbo');
	}

	return $alt_text;
}

/**
 * Returns the contents div of blog
 *
 * @since  1.0.0
 */

if( !function_exists('retbo_before_blog_content') ) {

  function retbo_before_blog_content() {

    // Return it for full width or full screen
    if(in_array(retbo_post_layout(), array('full-screen', 'full-width'))) {
       $div_content = '<div class="col-xl-12 blog-post-items">';
    }

    // Return for both sidebars
    elseif('no-sidebar' == retbo_post_layout()) {
      	$div_content = '<div class="col-xl-8 offset-xl-2 col-lg-10 offset-lg-1 blog-post-items">';
    }

     // Return for single sidebar
    else {
    	$div_content = '<div class="col-xl-8 blog-post-items">';
    }
  	
    print wp_kses_post($div_content);
    
  }

  add_action('retbo_before_blog_content', 'retbo_before_blog_content');

}


/**
 * Returns the contents div of page
 *
 * @since  1.0.0
 */
if( !function_exists('retbo_before_content') ) {

  function retbo_before_content() {

    // Return it for full width or full screen
    if(in_array(retbo_post_layout(), array('full-screen', 'full-width'))) {
       $div_content = '<div class="col-xl-12">';
    }

    // Return for both sidebars
    elseif('no-sidebar' == retbo_post_layout()) {
  		$div_content = '<div class="col-xl-8 offset-xl-2 col-lg-10 offset-lg-1">';
    }

     // Return for single sidebar
    else {
    	$div_content = '<div class="col-xl-8">';
    }
  	
    print wp_kses_post($div_content);
    
  }

  add_action('retbo_before_content', 'retbo_before_content');

}


/**
 * Returns the contents div
 *
 * @since  1.0.0
 */
if( !function_exists('retbo_after_content') ) {

  function retbo_after_content() {
    
    // Return for content closing div
    print '</div>';
    
  }

  add_action('retbo_after_content', 'retbo_after_content');

}


/**
 * Returns the sidebar
 *
 * @since  1.0.0
 */
if( !function_exists('retbo_display_sidebar') ) {

  function retbo_display_sidebar() {

    // Retunr if full width or full screen
    if(in_array(retbo_post_layout(), array('full-screen', 'full-width', 'no-sidebar'))) {
      return;
    }
    
    // Add the default sidebar
    get_sidebar();
    
  }

  add_action('retbo_display_sidebar', 'retbo_display_sidebar');

}

/**
 * Returns the sidebar
 *
 * @since  1.0.0
 */
if( !function_exists('retbo_sidebar_position') ) {

  function retbo_sidebar_position() {

    // Return sidebar class
    if(  'left-sidebar' == retbo_post_layout()) {
      return 'order-first';
    }
    // Retunr if full width or full screen
    else {
    	return '';
    }

  }

}

/**
 * Returns the post layout
 *
 * @since 1.0.0
 */
if( !function_exists('blog_content_layout') ) {

	function blog_content_layout() {

		// Define variables
		$meta   = get_post_meta(retbo_post_id(), 'blog_content_styles', true);

		// Check meta value from page
		if($meta) {
			return $meta;
		}

	}

}


/**
 * Returns the post layout
 *
 * @since 1.0.0
 */

function retbo_post_layout() {

	// Define variables
	$meta = get_post_meta(retbo_post_id(), 'content_layout_style', true);

	// Check meta value from page
	if($meta) {
		return $meta;
	}

}


/**
 * Get post ID
 *
 * @since 1.0.0
 */
function retbo_post_id() {

	//initial
	$id = get_the_ID();

	// If singular get_the_ID
	if(is_singular()) {
		$id = get_the_ID();
	}

	// Get Product ID of WooCommerce
	elseif(RETBO_WOOCOMMERCE_ACTIVED && is_shop()) {
		$shop_id = wc_get_page_id('shop');
		if(isset($shop_id)) {
			$id = $shop_id;
		}
	}

	// Posts page
	elseif(is_home() && $page_for_posts = get_option('page_for_posts')) {
		$id = $page_for_posts;
	}

	// Sanitize
	$id = $id ? $id : '';

	// Return ID
	return $id;

}




// retbo_member_sidebar_func
function retbo_member_sidebar_func() {
	if(is_active_sidebar('members-sidebar')){

		dynamic_sidebar( 'members-sidebar');
	}
}
add_action('retbo_member_sidebar','retbo_member_sidebar_func',20);

// retbo_service_sidebar
function retbo_service_sidebar_func() {
	if(is_active_sidebar('services-sidebar')){

		dynamic_sidebar( 'services-sidebar');
	}
}
add_action('retbo_service_sidebar','retbo_service_sidebar_func',20);

// retbo_portfolio_sidebar
function retbo_portfolio_sidebar_func() {
	if(is_active_sidebar('portfolio-sidebar')){

		dynamic_sidebar( 'portfolio-sidebar');
	}
}
add_action('retbo_portfolio_sidebar','retbo_portfolio_sidebar_func',20);