<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package retbo
 */

/**
 *
 * retbo header
 */

function retbo_check_header()
{
    $retbo_header_style = function_exists('get_field') ? get_field('header_style') : NULL;
    $retbo_default_header_style = get_theme_mod('choose_default_header', 'header-style-1');

    if ($retbo_header_style == 'header-style-1') {
        retbo_header_style_1();
    } elseif ($retbo_header_style == 'header-style-2') {
        retbo_header_style_2();
    } elseif ($retbo_header_style == 'header-style-3') {
        retbo_header_style_3();
    } elseif ($retbo_header_style == 'header-style-4') {
        retbo_header_style_4();
    } elseif ($retbo_header_style == 'header-style-5') {
        retbo_header_style_5();
    } elseif ($retbo_header_style == 'header-style-6') {
        retbo_header_style_6();
    } else {
        /** default header style **/
        if ($retbo_default_header_style == 'header-style-1') {
            retbo_header_style_1();
        } elseif ($retbo_default_header_style == 'header-style-2') {
            retbo_header_style_2();
        } elseif ($retbo_default_header_style == 'header-style-3') {
            retbo_header_style_3();
        } elseif ($retbo_default_header_style == 'header-style-4') {
            retbo_header_style_4();
        } elseif ($retbo_default_header_style == 'header-style-5') {
            retbo_header_style_5();
        } else {
            retbo_header_style_6();
        }
    }

}

add_action('retbo_header_style', 'retbo_check_header', 10);

/**
 * header style 1
 */

function retbo_header_style_1()
{
    $retbo_topbar_switch = get_theme_mod('retbo_topbar_switch');
    $retbo_header_search = get_theme_mod('retbo_header_search');
    $retbo_header_right = get_theme_mod('retbo_header_right');
    $retbo_cart_link = get_theme_mod('retbo_cart_link');
    $retbo_account_link = get_theme_mod('retbo_account_link');
    $retbo_wishlist_link = get_theme_mod('retbo_wishlist_link', false);
    $retbo_account_switch = get_theme_mod('retbo_account_switch', false);
    $retbo_wishlist_switch = get_theme_mod('retbo_wishlist_switch', false);
    $retbo_news_title = get_theme_mod('retbo_news_title');

    $header_menu_col = $retbo_header_right ? 'col-xl-8 col-lg-8' : 'col-xl-10 col-lg-10 text-right';
    $header_menu_pos = $retbo_header_right ? 'text-center' : 'text-right';

    ?>
    <!-- header begin -->
    <header class="header-h-two">
        <?php if ($retbo_topbar_switch): ?>
            <div class="top-border-two d-none d-lg-block">
                <div class="container">
                    <div class="row align-items-center">
                        <?php if (!empty($retbo_news_title)): ?>
                            <div class="col-lg-4 col-md-5 col-12">
                                <div class="news-title">
                                    <p><?php print wp_kses_post($retbo_news_title); ?></p>
                                </div>
                            </div>
                        <?php endif; ?>
                        <?php if (has_nav_menu('top-menu')) : ?>
                            <div class="col-lg-8 col-md-7 col-12">
                                <div class="header-top-right text-right">
                                    <?php retbo_top_menu(); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <!-- menu-area -->
        <div class="header-menu-two">
            <div class="container">
                <div class="row align-items-center">

                    <div class="col-xl-2 col-lg-2 col-md-4 col-4">
                        <div class="logo">
                            <?php retbo_header_logo(); ?>
                        </div>
                    </div>

                    <div class="<?php print esc_attr($header_menu_col); ?> col-md-12 d-none d-lg-block">
                        <div class="main-menu <?php print esc_attr($header_menu_pos); ?>">
                            <nav id="mobile-menu">
                                <?php retbo_header_menu(); ?>
                            </nav>
                        </div>
                    </div>

                    <div class="col-xl-2 col-lg-2 col-md-7 col-6">
                        <div class="header-left-icon d-flex align-items-center f-right">
                            <?php if ($retbo_header_search): ?>
                                <a class="search-btn nav-search search-trigger" href="#">
                                    <i class="fas fa-search"></i>
                                </a>
                            <?php endif; ?>

                            <?php if ( !empty($retbo_account_switch) && RETBO_WOOCOMMERCE_ACTIVED ): ?>
                                <?php if (is_user_logged_in()): ?>
                                <a href="<?php echo get_permalink(wc_get_page_id('myaccount')); ?>">
                                    <i class="fas fa-user"></i>
                                </a>
                                <?php else : ?>
                                <a href="<?php echo wp_logout_url(get_permalink(wc_get_page_id('myaccount'))) ?>">
                                    <i class="fas fa-user"></i>
                                </a>
                                <?php endif; ?>
                            <?php endif; ?>

                            <?php if ($retbo_wishlist_switch): ?>
                                <a href="<?php print esc_url($retbo_wishlist_link); ?>">
                                    <i class="fas fa-heart"></i>
                                </a>
                            <?php endif; ?>

                            <?php if ( RETBO_WOOCOMMERCE_ACTIVED ): ?>
                                <a href="<?php echo wc_get_cart_url(); ?>" class="shopping-cart-btn">
                                    <i class="fas fa-cart-arrow-down"></i>
                                    <span id="retbo-cart-item">
                                        <?php echo esc_html(WC()->cart->cart_contents_count); ?>
                                    </span>
                                </a>
                            <?php endif; ?>
                        </div>
                    </div>

                    <div class="col-2 col-md-1 d-block d-lg-none">
                        <div class="hamburger-menu text-right">
                            <a href="javascript:void(0);">
                                <i class="fal fa-bars"></i>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </header>
    <?php retbo_extra_info(); ?>
    <!-- header end -->
    <?php print retbo_shopping_cart(); ?>
    <?php


}

/**
 * header style 2
 */

function retbo_header_style_2()
{
    $retbo_header_search = get_theme_mod('retbo_header_search');
    $retbo_header_right = get_theme_mod('retbo_header_right');
    $retbo_header_cart = get_theme_mod('retbo_header_cart');
    $retbo_account_link = get_theme_mod('retbo_account_link');
    $retbo_account_switch = get_theme_mod('retbo_account_switch', false);
    $retbo_wishlist_link = get_theme_mod('retbo_wishlist_link');
    ?>
    <!-- header begin -->
    <header class="header-h-two">
        <!-- menu-area -->
        <div class="product-details-header ml-35 mr-35">
            <div class="container-fluid">
                <div class="row align-items-center">
                    <?php if (has_nav_menu('main-menu')) : ?>
                        <div class="col-xl-5 col-lg-6 col-md-12 d-none d-lg-block">
                            <div class="main-menu product-details-menu">
                                <nav id="mobile-menu-four">
                                    <?php retbo_header_menu(); ?>
                                </nav>
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="col-xl-2 col-lg-3 col-md-4 col-5">
                        <div class="logo product-details-logo">
                            <?php retbo_header_logo(); ?>
                        </div>
                    </div>

                    <div class="col-xl-5 col-lg-3 col-md-7 col-5 header-6-padd">
                        <div class="header-left-icon d-flex align-items-center f-right">
                            <?php if ($retbo_header_search): ?>
                                <a class="search-btn nav-search search-trigger" href="#">
                                    <i class="fas fa-search"></i>
                                </a>
                            <?php endif; ?>

                            <?php if ( !empty($retbo_account_switch) && RETBO_WOOCOMMERCE_ACTIVED ): ?>
                                <?php if (is_user_logged_in()): ?>
                                <a href="<?php echo get_permalink(wc_get_page_id('myaccount')); ?>">
                                    <i class="fas fa-user"></i>
                                </a>
                                <?php else : ?>
                                <a href="<?php echo wp_logout_url(get_permalink(wc_get_page_id('myaccount'))) ?>">
                                    <i class="fas fa-user"></i>
                                </a>
                                <?php endif; ?>
                            <?php endif; ?>

                            <?php if ($retbo_wishlist_link): ?>
                                <a href="<?php print esc_url($retbo_wishlist_link); ?>">
                                    <i class="fas fa-heart"></i>
                                </a>
                            <?php endif; ?>

                            <?php if (RETBO_WOOCOMMERCE_ACTIVED): ?>
                                <a href="<?php echo wc_get_cart_url(); ?>" class="shopping-cart-btn">
                                    <i class="fas fa-cart-arrow-down"></i>
                                    <span id="retbo-cart-item">
                                        <?php echo esc_html(WC()->cart->cart_contents_count); ?>
                                    </span>
                                </a>
                            <?php endif; ?>

                        </div>
                    </div>

                    <div class="col-2 col-md-1 d-block d-lg-none">
                        <div class="hamburger-menu text-right">
                            <a href="javascript:void(0);">
                                <i class="fal fa-bars"></i>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </header>
    <!-- header end -->

    <?php retbo_extra_info(); ?>
    <!-- header end -->

    <?php print retbo_shopping_cart(); ?>
    <?php


}

/**
 * header style 3
 */

function retbo_header_style_3()
{
    $retbo_topbar_switch = get_theme_mod('retbo_topbar_switch');
    $retbo_header_search = get_theme_mod('retbo_header_search');
    $retbo_header_right = get_theme_mod('retbo_header_right');
    $retbo_cart_link = get_theme_mod('retbo_cart_link');
    $retbo_account_link = get_theme_mod('retbo_account_link');
    $retbo_account_switch = get_theme_mod('retbo_account_switch', false);
    $retbo_wishlist_link = get_theme_mod('retbo_wishlist_link');

    $retbo_features_text_1 = get_theme_mod('retbo_features_text_1');
    $retbo_features_text_2 = get_theme_mod('retbo_features_text_2');
    $retbo_features_text_3 = get_theme_mod('retbo_features_text_3');
    ?>
    <!-- header begin -->
    <header class="header-h-three">
        <?php if ($retbo_topbar_switch): ?>
            <div class="dark-bg">
                <div class="container-fluid">
                    <div class="row align-items-center">
                        <div class="col-12 d-none d-md-block">
                            <div class="header-features header-features-three text-center">
                                <?php if ($retbo_features_text_1): ?>
                                    <span><?php print esc_html($retbo_features_text_1); ?></span>
                                <?php endif; ?>
                                <?php if ($retbo_features_text_2): ?>
                                    <span><?php print esc_html($retbo_features_text_2); ?></span>
                                <?php endif; ?>
                                <?php if ($retbo_features_text_3): ?>
                                    <span><?php print esc_html($retbo_features_text_3); ?></span>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <!-- menu-area -->
        <div class="header-menu-two black-bg header-space">
            <div class="container-fluid">
                <div class="row align-items-center">
                    <div class="col-xl-2 col-lg-2 col-md-4 col-4">
                        <div class="logo">
                            <?php retbo_header_logo(); ?>
                        </div>
                    </div>
                    <div class="col-xl-8 col-lg-8 col-md-12 d-none d-lg-block">
                        <div class="main-menu main-menu-3 text-center">
                            <nav id="mobile-menu">
                                <?php retbo_header_menu(); ?>
                            </nav>
                        </div>
                    </div>
                    <?php if ($retbo_header_right): ?>
                        <div class="col-xl-2 col-lg-2 col-md-7 col-6">
                            <div class="header-left-icon header-right-icon d-flex align-items-center f-right">
                                <?php if ($retbo_header_search): ?>
                                    <a class="search-btn nav-search search-trigger" href="#">
                                        <i class="fas fa-search"></i>
                                    </a>
                                <?php endif; ?>

                                <?php if ( !empty($retbo_account_switch) && RETBO_WOOCOMMERCE_ACTIVED ): ?>
                                    <?php if (is_user_logged_in()): ?>
                                    <a href="<?php echo get_permalink(wc_get_page_id('myaccount')); ?>">
                                        <i class="fas fa-user"></i>
                                    </a>
                                    <?php else : ?>
                                    <a href="<?php echo wp_logout_url(get_permalink(wc_get_page_id('myaccount'))) ?>">
                                        <i class="fas fa-user"></i>
                                    </a>
                                    <?php endif; ?>
                                <?php endif; ?>

                                <?php if ($retbo_wishlist_link): ?>
                                    <a href="<?php print esc_url($retbo_wishlist_link); ?>">
                                        <i class="fas fa-heart"></i>
                                    </a>
                                <?php endif; ?>

                                <?php if (RETBO_WOOCOMMERCE_ACTIVED): ?>
                                <a href="<?php echo wc_get_cart_url(); ?>" class="shopping-cart-btn">
                                    <i class="fas fa-cart-arrow-down"></i>
                                    <span id="retbo-cart-item">
                                        <?php echo esc_html(WC()->cart->cart_contents_count); ?>
                                    </span>
                                </a>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endif; ?>
                    <div class="col-2 col-md-1 d-block d-lg-none">
                        <div class="hamburger-menu text-right">
                            <a href="javascript:void(0);">
                                <i class="fal fa-bars"></i>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </header>
    <!-- header end -->

    <?php retbo_extra_info(); ?>
    <?php print retbo_shopping_cart(); ?>
    <?php
}

/**
 * header style 4
 */
function retbo_header_style_4()
{
    $retbo_topbar_switch = get_theme_mod('retbo_topbar_switch');
    $retbo_header_search = get_theme_mod('retbo_header_search');
    $retbo_header_right = get_theme_mod('retbo_header_right');
    $retbo_cart_link = get_theme_mod('retbo_cart_link');
    $retbo_account_link = get_theme_mod('retbo_account_link');
    $retbo_account_switch = get_theme_mod('retbo_account_switch', false);
    $retbo_wishlist_link = get_theme_mod('retbo_wishlist_link');

    $retbo_phone_number = get_theme_mod('retbo_phone_number');
    $retbo_phone_content = get_theme_mod('retbo_phone_content');
    $retbo_update_covid = get_theme_mod('retbo_update_covid');
    ?>
    <!-- header begin -->
    <header class="header-h-four">
        <?php if ($retbo_topbar_switch): ?>
            <div class="container">
                <div class="top-border-four">
                    <div class="row align-items-center">
                        <?php if (!empty($retbo_phone_number)): ?>
                            <div class="col-lg-3 col-sm-6 col-12">
                                <div class="emg-text">
                                    <p>
                                        <i class="fas fa-mobile-alt"></i>
                                        <?php print wp_kses_post($retbo_phone_number); ?>
                                    </p>
                                </div>
                            </div>
                        <?php endif; ?>
                        <?php if (!empty($retbo_phone_content)): ?>
                            <div class="col-lg-6 col-12 d-none d-lg-block">
                                <div class="promo-text text-center">
                                    <span class="f-400"><?php print wp_kses_post($retbo_phone_content); ?></span>
                                </div>
                            </div>
                        <?php endif; ?>
                        <?php if (!empty($retbo_update_covid)): ?>
                            <div class="col-lg-3 col-sm-6 d-none d-sm-block">
                                <div class="update-text">
                                    <div class="up-icon">
                                        <i class="fal fa-clock"></i>
                                    </div>
                                    <div class="up-content">
                                        <?php print wp_kses_post($retbo_update_covid); ?>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <!-- menu-area -->
        <div class="header-menu-two">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-xl-2 col-lg-2 col-md-4 col-md-4 col-4">
                        <div class="logo">
                            <?php retbo_header_logo(); ?>
                        </div>
                    </div>
                    <div class="col-xl-8 col-lg-8 d-none d-lg-block">
                        <div class="main-menu main-menu-4 text-center">
                            <nav id="mobile-menu-four">
                                <?php retbo_header_menu(); ?>
                            </nav>
                        </div>
                    </div>
                    <?php if ($retbo_header_right): ?>
                        <div class="col-xl-2 col-lg-2 col-md-7 col-6">
                            <div class="header-left-icon header-left-icon4 d-flex align-items-center f-right">
                                <?php if ($retbo_header_search): ?>
                                    <a class="search-btn nav-search search-trigger" href="#">
                                        <i class="fas fa-search"></i>
                                    </a>
                                <?php endif; ?>

                                <?php if ( !empty($retbo_account_switch) && RETBO_WOOCOMMERCE_ACTIVED ): ?>
                                    <?php if (is_user_logged_in()): ?>
                                    <a href="<?php echo get_permalink(wc_get_page_id('myaccount')); ?>">
                                        <i class="fas fa-user"></i>
                                    </a>
                                    <?php else : ?>
                                    <a href="<?php echo wp_logout_url(get_permalink(wc_get_page_id('myaccount'))) ?>">
                                        <i class="fas fa-user"></i>
                                    </a>
                                    <?php endif; ?>
                                <?php endif; ?>

                                <?php if ($retbo_wishlist_link): ?>
                                    <a href="<?php print esc_url($retbo_wishlist_link); ?>">
                                        <i class="fas fa-heart"></i>
                                    </a>
                                <?php endif; ?>

                                <?php if (RETBO_WOOCOMMERCE_ACTIVED): ?>
                                    <a href="<?php echo wc_get_cart_url(); ?>" class="shopping-cart-btn">
                                        <i class="fas fa-cart-arrow-down"></i>
                                        <span id="retbo-cart-item">
                                        <?php echo esc_html(WC()->cart->cart_contents_count); ?>
                                    </span>
                                    </a>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endif; ?>
                    <div class="col-2 col-md-1 d-block d-lg-none">
                        <div class="hamburger-menu text-right">
                            <a href="javascript:void(0);">
                                <i class="fal fa-bars"></i>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </header>
    <!-- header end -->

    <?php retbo_extra_info(); ?>
    <?php print retbo_shopping_cart(); ?>
    <?php
}

/**
 * header style 5
 */
function retbo_header_style_5()
{
    $retbo_topbar_switch = get_theme_mod('retbo_topbar_switch');
    $retbo_header_search = get_theme_mod('retbo_header_search');
    $retbo_cart_link = get_theme_mod('retbo_cart_link');
    $retbo_account_link = get_theme_mod('retbo_account_link');
    $retbo_account_switch = get_theme_mod('retbo_account_switch', false);

    $retbo_phone_number = get_theme_mod('retbo_phone_number');
    $retbo_free_shipping = get_theme_mod('retbo_free_shipping');
    ?>
    <header class="header-h-five common-space-5">
        <?php if ($retbo_topbar_switch): ?>
            <div class="top-border-five d-none d-lg-block">
                <div class="container-fluid">
                    <div class="row align-items-center">
                        <div class="col-lg-6 d-none d-sm-block">
                            <div class="emg-text emg-text-five">
                                <?php if (!empty($retbo_phone_number)): ?>
                                    <p>
                                        <i class="fas fa-mobile-android-alt"></i>
                                        <?php print wp_kses_post($retbo_phone_number); ?>
                                    </p>
                                <?php endif; ?>
                                <?php if (!empty($retbo_free_shipping)): ?>
                                    <p class="border-left">
                                        <i class="far fa-clock"></i>
                                        <?php print wp_kses_post($retbo_free_shipping); ?>
                                    </p>
                                <?php endif; ?>
                            </div>
                        </div>

                        <?php if (has_nav_menu('top-menu')) : ?>
                            <div class="col-lg-6">
                                <div class="header-top-right text-right">
                                    <?php retbo_top_menu(); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <!-- menu-area -->
        <div class="header-menu-two">
            <div class="container-fluid">
                <div class="row align-items-center">
                    <div class="col-xl-2 col-lg-2 col-md-4 col-4">
                        <div class="logo">
                            <?php retbo_header_logo(); ?>
                        </div>
                    </div>
                    <div class="col-xl-4 col-lg-6 col-md-9 d-none d-lg-block">
                        <div class="main-menu main-menu-five">
                            <nav id="mobile-menu">
                                <?php retbo_header_menu(); ?>
                            </nav>
                        </div>
                    </div>

                    <div class="col-xl-3 col-lg-3 d-lg-none d-xl-block col-md-7 d-none">
                        <?php if ($retbo_header_search): ?>
                            <div class="search-five ml-35">
                                <form action="#">
                                    <input type="text" placeholder="Search For Fruit, Vegetables..">
                                    <button type="submit"><i class="far fa-search"></i></button>
                                </form>
                            </div>
                        <?php endif; ?>
                    </div>

                    <div class="col-xl-3 col-lg-4 col-md-7 col-6">
                        <div class="header-left-icon header-left-icon-5 d-flex align-items-center f-right">

                            <?php if ( !empty($retbo_account_switch) && RETBO_WOOCOMMERCE_ACTIVED ): ?>
                                <?php if (is_user_logged_in()): ?>
                                <a href="<?php echo get_permalink(wc_get_page_id('myaccount')); ?>">
                                    <i class="fas fa-user"></i>
                                </a>
                                <?php else : ?>
                                <a href="<?php echo wp_logout_url(get_permalink(wc_get_page_id('myaccount'))) ?>">
                                    <i class="fas fa-user"></i>
                                </a>
                                <?php endif; ?>
                            <?php endif; ?>

                            <?php if (RETBO_WOOCOMMERCE_ACTIVED): ?>
                            <div class="shop-cart shop-cart-5 d-none d-sm-inline-block">
                                <div class="text-right">
                                    <a href="<?php echo wc_get_cart_url(); ?>" class="shoppings-cart-btn">
                                        <h6 class="d-none d-md-inline-block">
                                            <?php print esc_html__('Shopping Bag', 'retbo'); ?> <span
                                                    id="retbo-cart-item"><?php echo esc_html(WC()->cart->cart_contents_count); ?></span>
                                        </h6>
                                    </a>
                                </div>
                            </div>
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="col-2 col-md-1 d-block d-lg-none">
                        <div class="hamburger-menu text-right">
                            <a href="javascript:void(0);">
                                <i class="fal fa-bars"></i>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </header>
    <!-- header end -->

    <?php retbo_extra_info(); ?>
    <?php print retbo_shopping_cart(); ?>
    <?php
}

/**
 * header style 6 default
 */
function retbo_header_style_6()
{
    $retbo_topbar_switch = get_theme_mod('retbo_topbar_switch');
    $retbo_header_search = get_theme_mod('retbo_header_search');
    $retbo_header_right = get_theme_mod('retbo_header_right');
    $retbo_cart_link = get_theme_mod('retbo_cart_link');
    $retbo_account_link = get_theme_mod('retbo_account_link');
    $retbo_account_switch = get_theme_mod('retbo_account_switch', false);
    $retbo_wishlist_link = get_theme_mod('retbo_wishlist_link');

    $retbo_features_text_1 = get_theme_mod('retbo_features_text_1');
    $retbo_features_text_2 = get_theme_mod('retbo_features_text_2');
    $retbo_features_text_3 = get_theme_mod('retbo_features_text_3');
    ?>
    <!-- header begin -->
    <header class="header-transparent">
        <?php if ($retbo_topbar_switch): ?>
            <div class="top-border">
                <div class="container-fluid">
                    <div class="row align-items-center">
                        <div class="col-12 d-none d-md-block">
                            <div class="header-features text-center">
                                <?php if ($retbo_features_text_1): ?>
                                    <span><?php print esc_html($retbo_features_text_1); ?></span>
                                <?php endif; ?>
                                <?php if ($retbo_features_text_2): ?>
                                    <span><?php print esc_html($retbo_features_text_2); ?></span>
                                <?php endif; ?>
                                <?php if ($retbo_features_text_3): ?>
                                    <span><?php print esc_html($retbo_features_text_3); ?></span>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <!-- menu-area -->
        <div class="header-menu-area logo-circle-area">
            <div class="container-fluid">
                <div class="row align-items-center">

                    <?php if ($retbo_header_right): ?>
                        <div class="col-xl-3 col-lg-3 col-md-3 col-12">
                            <div class="header-left-icon d-flex align-items-center justify-content-center justify-content-md-left">
                                <?php if (has_nav_menu('main-menu')) : ?>
                                    <div class="basic-bar hamburger-menu">
                                        <a href="javascript:void(0);">
                                            <span class="bar1"></span>
                                            <span class="bar2"></span>
                                            <span class="bar3"></span>
                                        </a>
                                    </div>
                                <?php endif; ?>

                                <?php if ($retbo_header_search): ?>
                                    <a class="search-btn nav-search search-trigger" href="#">
                                        <i class="fas fa-search"></i>
                                    </a>
                                <?php endif; ?>

                                <?php if ($retbo_wishlist_link): ?>
                                    <a href="<?php print esc_url($retbo_wishlist_link); ?>">
                                        <i class="fas fa-heart"></i>
                                    </a>
                                <?php endif; ?>

                                <?php if ( !empty($retbo_account_switch) && RETBO_WOOCOMMERCE_ACTIVED ): ?>
                                    <?php if (is_user_logged_in()): ?>
                                    <a href="<?php echo get_permalink(wc_get_page_id('myaccount')); ?>">
                                        <i class="fas fa-user"></i>
                                    </a>
                                    <?php else : ?>
                                    <a href="<?php echo wp_logout_url(get_permalink(wc_get_page_id('myaccount'))) ?>">
                                        <i class="fas fa-user"></i>
                                    </a>
                                    <?php endif; ?>
                                <?php endif; ?>

                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="col-xl-6 col-lg-5 col-md-4 col-5">
                        <div class="logo pt-45 pb-45 text-left text-lg-center">
                            <?php retbo_header_logo(); ?>
                        </div>
                    </div>

                    <?php if (RETBO_WOOCOMMERCE_ACTIVED): ?>
                    <div class="col-xl-3 col-lg-4 col-md-5 col-7">
                        <div class="shop-cart">
                            <div class="text-right">
                                <a href="<?php echo wc_get_cart_url(); ?>" class="shopping-cart-btn">
                                    <h6 class="d-none d-md-inline-block">
                                        <?php print esc_html__('Shopping Bag', 'retbo'); ?> <span
                                                id="retbo-cart-item"><?php echo esc_html(WC()->cart->cart_contents_count); ?></span>
                                    </h6>
                                    <h6 class="d-inline-block d-md-none">
                                        <?php print esc_html__('Cart', 'retbo'); ?>
                                        <span id="retbo-cart-item-md"><?php echo esc_html(WC()->cart->cart_contents_count); ?></span>
                                    </h6>
                                    <div class="cart-price"
                                         id="retbo-total-price"><?php echo WC()->cart->get_cart_total(); ?></div>
                                </a>
                            </div>
                        </div>
                    </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </header>

    <?php retbo_extra_info(); ?>
    <?php print retbo_shopping_cart(); ?>
    <?php
}


/**
 * [retbo_extra_info description]
 * @return [type] [description]
 */
function retbo_extra_info()
{
    $retbo_logo = get_template_directory_uri() . '/assets/img/logo/logo.png';
    $retbo_site_logo = get_theme_mod('mobile_menu_logo', $retbo_logo);
    ?>
    <!-- slide-bar start -->
    <aside class="slide-bar">
        <div class="close-mobile-menu">
            <a href="javascript:void(0);"><i class="fas fa-times"></i></a>
        </div>

        <div class="mobile-logo">
            <a href="<?php print esc_url(home_url('/')); ?>">
                <img src="<?php print esc_url($retbo_site_logo); ?>" alt="<?php print esc_attr('logo', 'retbo'); ?>"/>
            </a>
        </div>

        <!-- side-mobile-menu start -->
        <nav class="side-mobile-menu">
            <?php retbo_mobile_menu() ?>
        </nav>
        <!-- side-mobile-menu end -->
    </aside>
    <div class="body-overlay"></div>
    <!-- slide-bar end -->

    <!-- Fullscreen search -->
    <?php print retbo_search_form(); ?>
    <!-- end fullscreen search -->
<?php }

/**
 * [retbo_header_lang description]
 * @return [type] [description]
 */
function retbo_header_lang_defualt()
{
    $retbo_header_lang = get_theme_mod('retbo_header_lang');
    if ($retbo_header_lang): ?>
        <div class="header-lang pos-rel f-right d-none d-xl-block">
            <div class="lang-icon">
                <img src="<?php print get_template_directory_uri(); ?>/img/icon/flag.png"
                     alt="<?php print esc_attr__('logo', 'retbo'); ?>">
                <a href="#"><?php print esc_html__('English', 'retbo'); ?> <i class="far fa-angle-down"></i></a>
            </div>
            <?php do_action('retbo_language'); ?>
        </div>
    <?php endif; ?>
    <?php
}


/**
 * [retbo_language_list description]
 * @return [type] [description]
 */
function _retbo_language($mar)
{
    return $mar;
}

function retbo_language_list()
{

    $mar = '';
    $languages = apply_filters('wpml_active_languages', NULL, 'orderby=id&order=desc');
    if (!empty($languages)) {
        $mar = '<ul class="header-lang-list">';
        foreach ($languages as $lan) {
            $active = $lan['active'] == 1 ? 'active' : '';
            $mar .= '<li class="' . $active . '"><a href="' . $lan['url'] . '">' . $lan['translated_name'] . '</a></li>';
        }
        $mar .= '</ul>';
    } else {
        //remove this code when send themeforest reviewer team
        $mar .= '<ul class="header-lang-list">';
        $mar .= '<li><a href="#">' . esc_html__('English', 'retbo') . '</a></li>';
        $mar .= '<li><a href="#">' . esc_html__('Arabic', 'retbo') . '</a></li>';
        $mar .= '<li><a href="#">' . esc_html__('Hindi', 'retbo') . '</a></li>';
        $mar .= ' </ul>';
    }
    print _retbo_language($mar);
}

add_action('retbo_language', 'retbo_language_list');

// favicon logo
function retbo_favicon_logo_func()
{
    $retbo_favicon = get_template_directory_uri() . '/assets/img/logo/favicon.png';
    $retbo_favicon_url = get_theme_mod('favicon_url', $retbo_favicon);
    ?>

    <link rel="shortcut icon" type="image/x-icon" href="<?php print esc_url($retbo_favicon_url); ?>">

    <?php
}

add_action('wp_head', 'retbo_favicon_logo_func');

// header logo

function retbo_header_logo()
{
    ?>
    <?php
    $retbo_logo_on = function_exists('get_field') ? get_field('is_enable_sec_logo') : NULL;
    $retbo_logo = get_template_directory_uri() . '/assets/img/logo/logo.png';
    $retbo_logo_white = get_template_directory_uri() . '/assets/img/logo/logo-white.png';

    $retbo_site_logo = get_theme_mod('logo', $retbo_logo);
    $retbo_secondary_logo = get_theme_mod('seconday_logo', $retbo_logo_white);
    ?>

    <?php
    if (has_custom_logo()) {
        the_custom_logo();
    } else {

        if (!empty($retbo_logo_on)) { ?>
            <a class="standard-logo" href="<?php print esc_url(home_url('/')); ?>">
                <img src="<?php print esc_url($retbo_secondary_logo); ?>"
                     alt="<?php print esc_attr('logo', 'retbo'); ?>"/>
            </a>
            <?php
        } else { ?>
            <a class="standard-logo-white" href="<?php print esc_url(home_url('/')); ?>">
                <img src="<?php print esc_url($retbo_site_logo); ?>" alt="<?php print esc_attr('logo', 'retbo'); ?>"/>
            </a>
            <?php
        }
    }
    ?>
    <?php
}


/**
 * [retbo_header_social_profiles description]
 * @return [type] [description]
 */
function retbo_header_social_profiles()
{
    $retbo_topbar_fb_url = get_theme_mod('retbo_topbar_fb_url', '#');
    $retbo_topbar_twitter_url = get_theme_mod('retbo_topbar_twitter_url', '#');
    $retbo_topbar_instagram_url = get_theme_mod('retbo_topbar_instagram_url', '#');
    $retbo_topbar_linkedin_url = get_theme_mod('retbo_topbar_linkedin_url', '#');
    $retbo_topbar_youtube_url = get_theme_mod('retbo_topbar_youtube_url', '#');
    ?>
    <?php if (!empty($retbo_topbar_fb_url)): ?>
    <a href="<?php print esc_url($retbo_topbar_fb_url); ?>"><i class="fab fa-facebook"></i></a>
<?php endif; ?>

    <?php if (!empty($retbo_topbar_twitter_url)): ?>
    <a href="<?php print esc_url($retbo_topbar_twitter_url); ?>"><i class="fab fa-twitter"></i></a>
<?php endif; ?>

    <?php if (!empty($retbo_topbar_instagram_url)): ?>
    <a href="<?php print esc_url($retbo_topbar_instagram_url); ?>"><i class="fab fa-instagram"></i></a>
<?php endif; ?>

    <?php if (!empty($retbo_topbar_linkedin_url)): ?>
    <a href="<?php print esc_url($retbo_topbar_linkedin_url); ?>"><i class="fab fa-linkedin"></i></a>
<?php endif; ?>

    <?php if (!empty($retbo_topbar_youtube_url)): ?>
    <a href="<?php print esc_url($retbo_topbar_youtube_url); ?>"><i class="fab fa-youtube"></i></a>
<?php endif; ?>
    <?php
}


function retbo_footer_social()
{
    $retbo_footer_fb_url = get_theme_mod('retbo_footer_fb_url', '#');
    $retbo_footer_twitter_url = get_theme_mod('retbo_footer_twitter_url', '#');
    $retbo_footer_instagram_url = get_theme_mod('retbo_footer_instagram_url', '#');
    $retbo_footer_linkedin_url = get_theme_mod('retbo_footer_linkedin_url', '#');
    $retbo_footer_youtube_url = get_theme_mod('retbo_footer_youtube_url', '#');
    ?>
    <div class="social-icon mb-20">
        <?php if ($retbo_footer_fb_url): ?>
            <a href="<?php print esc_url($retbo_footer_fb_url); ?>">
                <i class="fab fa-facebook-f"></i>
            </a>
        <?php endif; ?>

        <?php if ($retbo_footer_twitter_url): ?>
            <a href="<?php print esc_url($retbo_footer_twitter_url); ?>">
                <i class="fab fa-twitter"></i>
            </a>
        <?php endif; ?>

        <?php if ($retbo_footer_instagram_url): ?>
            <a href="<?php print esc_url($retbo_footer_instagram_url); ?>">
                <i class="fab fa-instagram"></i>
            </a>
        <?php endif; ?>

        <?php if ($retbo_footer_linkedin_url): ?>
            <a href="<?php print esc_url($retbo_footer_linkedin_url); ?>">
                <i class="fab fa-linkedin-in"></i>
            </a>
        <?php endif; ?>

        <?php if ($retbo_footer_youtube_url): ?>
            <a href="<?php print esc_url($retbo_footer_youtube_url); ?>">
                <i class="fab fa-youtube"></i>
            </a>
        <?php endif; ?>
    </div>
    <?php
}


/**
 * [retbo_header_menu description]
 * @return [type] [description]
 */
function retbo_header_menu()
{
    $retbo_menu = wp_nav_menu(array(
        'theme_location' => 'main-menu',
        'menu_class' => '',
        'container' => '',
        'fallback_cb' => 'Navwalker_Class::fallback',
        'walker' => new Navwalker_Class,
        'echo' => false
    ));

    $retbo_menu = str_replace("menu-item-has-children", "menu-item-has-children dropdown-icon", $retbo_menu);
    $retbo_menu = str_replace("sub-menu", "sub-menu submenu", $retbo_menu);
    echo wp_kses_post($retbo_menu);
}

/**
 * [retbo_mobile_menu description]
 * @return [type] [description]
 */
function retbo_mobile_menu()
{ ?>
    <?php
    $retbo_menu = wp_nav_menu(array(
        'theme_location' => 'main-menu',
        'menu_class' => '',
        'container' => '',
        'menu_id' => 'mobile-menu-active',
        'echo' => false
    ));

    $retbo_menu = str_replace("menu-item-has-children", "menu-item-has-children has-dropdown", $retbo_menu);
    echo wp_kses_post($retbo_menu);
    ?>
    <?php
}


/**
 * [retbo_top_menu description]
 * @return [type] [description]
 */
function retbo_top_menu()
{ ?>
    <?php
    $retbo_menu = wp_nav_menu(array(
        'theme_location' => 'top-menu',
        'container' => '',
        'fallback_cb' => 'Navwalker_Class::fallback',
        'walker' => new Navwalker_Class,
        'echo' => false
    ));
    echo wp_kses_post($retbo_menu);
    ?>
    <?php
}

function retbo_header_3_menu()
{ ?>
    <?php
    wp_nav_menu(array(
        'theme_location' => 'main-menu',
        'menu_class' => '',
        'container' => '',
    ));
    ?>
    <?php
}


/**
 * [retbo_footer_menu description]
 * @return [type] [description]
 */
function retbo_footer_menu()
{

    wp_nav_menu(array(
        'theme_location' => 'footer-menu',
        'menu_class' => 'm-0',
        'container' => '',
        'fallback_cb' => 'Navwalker_Class::fallback',
        'walker' => new Navwalker_Class
    ));

}


/**
 *
 * retbo footer
 */
add_action('retbo_footer_style', 'retbo_check_footer', 10);

function retbo_check_footer()
{
    $retbo_footer_style = function_exists('get_field') ? get_field('footer_style') : NULL;
    $retbo_default_footer_style = get_theme_mod('choose_default_footer', 'footer-style-1');

    if ($retbo_footer_style == 'footer-style-1') {
        retbo_footer_style_1();
    } elseif ($retbo_footer_style == 'footer-style-2') {
        retbo_footer_style_2();
    } elseif ($retbo_footer_style == 'footer-style-3') {
        retbo_footer_style_3();
    } elseif ($retbo_footer_style == 'footer-style-4') {
        retbo_footer_style_4();
    } elseif ($retbo_footer_style == 'footer-style-5') {
        retbo_footer_style_5();
    } elseif ($retbo_footer_style == 'footer-style-6') {
        retbo_footer_style_6();
    } else {

        /** default footer style **/
        if ($retbo_default_footer_style == 'footer-style-1') {
            retbo_footer_style_1();
        } elseif ($retbo_default_footer_style == 'footer-style-2') {
            retbo_footer_style_2();
        } elseif ($retbo_default_footer_style == 'footer-style-3') {
            retbo_footer_style_3();
        } elseif ($retbo_default_footer_style == 'footer-style-4') {
            retbo_footer_style_4();
        } elseif ($retbo_default_footer_style == 'footer-style-5') {
            retbo_footer_style_5();
        } else {
            retbo_footer_style_6();
        }

    }
}

/**
 * footer  style 1
 */
function retbo_footer_style_1()
{
    $retbo_right_text = get_theme_mod('retbo_right_text', esc_html__('All Right Reserved By Theme_Pure.', 'retbo'));

    $footer_columns = 0;
    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        if (is_active_sidebar('footer-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-lg-4 col-md-6';
            $footer_class[2] = 'col-lg-4 col-md-6';
            $footer_class[3] = 'col-lg-4 col-md-6';
            break;
        case '4':
            $footer_class[1] = 'col-lg-3 col-md-6';
            $footer_class[2] = 'col-lg-3 col-md-6';
            $footer_class[3] = 'col-lg-3 col-md-6';
            $footer_class[4] = 'col-lg-3 col-md-6';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

    ?>
    <footer class="footer-default">
        <?php if (is_active_sidebar('footer-1') or is_active_sidebar('footer-2') or is_active_sidebar('footer-3') or is_active_sidebar('footer-4')): ?>
            <div class="footer-area pt-60 pb-55">
                <div class="container">
                    <div class="row">
                        <?php
                        if ($footer_columns < 4) {
                            print '<div class="col-lg-3 col-md-6">';
                            dynamic_sidebar('footer-1');
                            print '</div>';

                            print '<div class="col-lg-3 col-md-6">';
                            dynamic_sidebar('footer-2');
                            print '</div>';

                            print '<div class="col-lg-3 col-md-6">';
                            dynamic_sidebar('footer-3');
                            print '</div>';

                            print '<div class="col-lg-3 col-md-6">';
                            dynamic_sidebar('footer-4');
                            print '</div>';
                        } else {
                            for ($num = 1; $num <= $footer_columns; $num++) {
                                if (!is_active_sidebar('footer-' . $num)) continue;
                                print '<div class="' . esc_attr($footer_class[$num]) . '">';
                                dynamic_sidebar('footer-' . $num);
                                print '</div>';
                            }
                        }

                        ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <div class="copyright-two copyright-border">
            <div class="container">
                <div class="row">
                    <div class="col-md-6 col-12">
                        <div class="copyright-text">
                            <span><?php print retbo_copyright_text(); ?></span>
                        </div>
                    </div>
                    <?php if (!empty($retbo_right_text)): ?>
                        <div class="col-md-6 col-12">
                            <div class="copyright-text text-right">
                                <span><?php print esc_html($retbo_right_text); ?></span>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </footer>
    <?php
}

/**
 * footer  style 2
 */
function retbo_footer_style_2()
{
    $retbo_right_text = get_theme_mod('retbo_right_text', esc_html__('All Right Reserved By Theme_pure.', 'retbo'));

    $footer_columns = 0;
    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        if (is_active_sidebar('footer-2-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-lg-4 col-md-6';
            $footer_class[2] = 'col-lg-4 col-md-6';
            $footer_class[3] = 'col-lg-4 col-md-6';
            break;
        case '4':
            $footer_class[1] = 'col-lg-4 col-md-6';
            $footer_class[2] = 'col-lg-2 col-md-6';
            $footer_class[3] = 'col-lg-3 col-md-6';
            $footer_class[4] = 'col-lg-3 col-md-6';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

    ?>
    <footer>
        <?php if (is_active_sidebar('footer-2-1') or is_active_sidebar('footer-2-2') or is_active_sidebar('footer-2-3') or is_active_sidebar('footer-2-4')): ?>
            <div class="footer-area pt-60 pb-55">
                <div class="container">
                    <div class="row">
                        <?php
                        for ($num = 1; $num <= $footer_columns; $num++) {
                            if (!is_active_sidebar('footer-2-' . $num)) continue;
                            print '<div class="' . esc_attr($footer_class[$num]) . '">';
                            dynamic_sidebar('footer-2-' . $num);
                            print '</div>';
                        }
                        ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <div class="copyright-two copyright-border">
            <div class="container">
                <div class="row">
                    <div class="col-md-6 col-12">
                        <div class="copyright-text">
                            <span><?php print retbo_copyright_text(); ?></span>
                        </div>
                    </div>
                    <div class="col-md-6 col-12">
                        <div class="copyright-text text-right">
                            <span><?php print esc_html($retbo_right_text); ?></span>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </footer>
    <?php
}

/**
 * footer  style 3
 */
function retbo_footer_style_3()
{
    $retbo_right_text = get_theme_mod('retbo_right_text', esc_html__('All Right Reserved By Theme_pure.', 'retbo'));

    $footer_columns = 0;
    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        if (is_active_sidebar('footer-3-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-lg-4 col-md-6';
            $footer_class[2] = 'col-lg-4 col-md-6';
            $footer_class[3] = 'col-lg-4 col-md-6';
            break;
        case '4':
            $footer_class[1] = 'col-lg-4 col-md-6';
            $footer_class[2] = 'col-lg-2 col-md-6';
            $footer_class[3] = 'col-lg-3 col-md-6';
            $footer_class[4] = 'col-lg-3 col-md-6';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

    ?>
    <footer>
        <?php if (is_active_sidebar('footer-3-1') or is_active_sidebar('footer-3-2') or is_active_sidebar('footer-3-3') or is_active_sidebar('footer-3-4')): ?>
            <div class="footer-area black-bg pt-90 pb-55">
                <div class="container">
                    <div class="row">
                        <?php
                        for ($num = 1; $num <= $footer_columns; $num++) {
                            if (!is_active_sidebar('footer-3-' . $num)) continue;
                            print '<div class="' . esc_attr($footer_class[$num]) . '">';
                            dynamic_sidebar('footer-3-' . $num);
                            print '</div>';
                        }
                        ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <div class="copyright-two dark-bg">
            <div class="container">
                <div class="row">
                    <div class="col-md-6 col-12">
                        <div class="copyright-text copy-three">
                            <span><?php print retbo_copyright_text(); ?></span>
                        </div>
                    </div>
                    <div class="col-md-6 col-12">
                        <div class="copyright-text copy-three text-right">
                            <span><?php print esc_html($retbo_right_text); ?></span>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </footer>
    <?php
}

/**
 * footer  style 4
 */
function retbo_footer_style_4()
{
    $footer_columns = 0;
    $footer_widgets = get_theme_mod('footer_widget_number', 5);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        if (is_active_sidebar('footer-4-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12 custom-width-20';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6 custom-width-20';
            $footer_class[2] = 'col-lg-6 col-md-6 custom-width-20';
            break;
        case '3':
            $footer_class[1] = 'col-lg-4 col-md-6 custom-width-20';
            $footer_class[2] = 'col-lg-4 col-md-6 custom-width-20';
            $footer_class[3] = 'col-lg-4 col-md-6 custom-width-20';
            break;
        case '4':
            $footer_class[1] = 'col-lg-4 col-md-6 custom-width-20';
            $footer_class[2] = 'col-lg-2 col-md-6 custom-width-20';
            $footer_class[3] = 'col-lg-3 col-md-6 custom-width-20';
            $footer_class[4] = 'col-lg-3 col-md-6 custom-width-20';
            break;
        case '5':
            $footer_class[1] = 'col-xl-3 col-md-6 custom-width-20';
            $footer_class[2] = 'col-xl-3 col-md-6 custom-width-20';
            $footer_class[3] = 'col-xl-3 col-md-6 custom-width-20';
            $footer_class[4] = 'col-xl-3 col-md-6 custom-width-20';
            $footer_class[5] = 'col-xl-3 col-md-6 custom-width-20';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6 custom-width-20';
            break;
    }

    ?>
    <footer>
        <?php if (is_active_sidebar('footer-4-1') or is_active_sidebar('footer-4-2') or is_active_sidebar('footer-4-3') or is_active_sidebar('footer-4-4')): ?>
            <div class="footer-area footer-four pt-85 pb-55">
                <div class="container">
                    <div class="row">
                        <?php
                        for ($num = 1; $num <= $footer_columns; $num++) {
                            if (!is_active_sidebar('footer-4-' . $num)) continue;
                            print '<div class="' . esc_attr($footer_class[$num]) . '">';
                            dynamic_sidebar('footer-4-' . $num);
                            print '</div>';
                        }
                        ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <div class="copyright-four">
            <div class="container">
                <div class="copy-border-four">
                    <div class="row align-items-center">
                        <div class="col-md-7 col-12">
                            <div class="copy-four-text">
                                <span><?php print retbo_copyright_text(); ?></span>
                            </div>
                        </div>
                        <div class="col-md-5 col-12">
                            <div class="copyright-payment text-right">
                                <img src="<?php print get_template_directory_uri(); ?>/assets/img/footer/payment-four.png"
                                     class="img-fluid" alt="payment">
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </footer>
    <?php
}

/**
 * footer  style 4
 */
function retbo_footer_style_5()
{
    ?>
    <footer>
        <?php if (is_active_sidebar('footer-5-1') or is_active_sidebar('footer-5-2') or is_active_sidebar('footer-5-3') or is_active_sidebar('footer-5-4')): ?>
            <div class="footer-area black-bg-dark pt-80 pb-45">
                <div class="container">
                    <div class="row">
                        <?php if (is_active_sidebar('footer-5-1')): ?>
                            <div class="col-lg-4 col-md-6">
                                <?php dynamic_sidebar('footer-5-1'); ?>
                            </div>
                        <?php endif; ?>
                        <?php if (is_active_sidebar('footer-5-2') || is_active_sidebar('footer-5-3')): ?>
                            <div class="col-lg-5 col-md-6">
                                <div class="footer-widget-five widget-five-border mb-30">
                                    <?php dynamic_sidebar('footer-5-2'); ?>
                                    <?php dynamic_sidebar('footer-5-3'); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                        <?php if (is_active_sidebar('footer-5-4')): ?>
                            <div class="col-lg-3">
                                <div class="footer-widget-five ml-50 mb-30">
                                    <?php dynamic_sidebar('footer-5-4'); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <div class="copyright-five black-bg-dark">
            <div class="container">
                <div class="row">
                    <div class="col-sm-12">
                        <div class="copytext-five text-center">
                            <span><?php print retbo_copyright_text(); ?></span>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </footer>
    <?php
}

/**
 * footer  style 6 defaut
 */
function retbo_footer_style_6()
{
    $retbo_footer_social_switch = get_theme_mod('retbo_footer_social_switch');
    ?>
    <footer>
        <div class="copyright-area pt-65 pb-40">
            <div class="container">
                <div class="row">
                    <div class="col-sm-12">
                        <div class="copyright-wrapper text-center">
                            <?php
                            if (!empty($retbo_footer_social_switch)) {
                                retbo_footer_social();
                            }
                            ?>
                            <span><?php print retbo_copyright_text(); ?></span>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </footer>
    <?php
}

function retbo_copyright_text()
{
    if (rtl_enable()) {
        print get_theme_mod('retbo_copyright_rtl', esc_html__('© 2022, Retbo Theme. Made with passion by Theme_Pure.', 'retbo'));
    } else {
        print get_theme_mod('retbo_copyright', esc_html__('© 2022, Retbo Theme. Made with passion by Theme_Pure.', 'retbo'));
    }
}

/**
 * [retbo_breadcrumb_func description]
 * @return [type] [description]
 */
function retbo_breadcrumb_func()
{

    $breadcrumb_class = '';
    $breadcrumb_show = 1;

    if (is_front_page() && is_home()) {
        $title = get_theme_mod('breadcrumb_blog_title', __('Blog', 'retbo'));
        $breadcrumb_class = 'home_front_page';

    } elseif (is_front_page()) {
        $title = get_theme_mod('breadcrumb_blog_title', __('Blog', 'retbo'));
        $breadcrumb_show = 0;
    } elseif (is_home()) {
        if (get_option('page_for_posts')) {
            $title = get_the_title(get_option('page_for_posts'));
        }
    } elseif (is_single() && 'post' == get_post_type()) {
        if (rtl_enable())
            $title = get_the_title();
        else
            $title = get_the_title();
    } elseif (is_single() && 'product' == get_post_type()) {
        $title = get_theme_mod('breadcrumb_product_details', __('Shop', 'retbo'));
    } elseif (is_single() && 'bdevs-department' == get_post_type()) {
        if (rtl_enable())
            $title = get_theme_mod('breadcrumb_department_details_rtl', __('Department', 'retbo'));
        else
            $title = get_theme_mod('breadcrumb_department_details', __('Department', 'retbo'));

    } elseif (is_single() && 'bdevs-doctor' == get_post_type()) {
        if (rtl_enable())
            $title = get_theme_mod('breadcrumb_doctor_details_rtl', __('Doctor', 'retbo'));
        else
            $title = get_theme_mod('breadcrumb_doctor_details', __('Doctor', 'retbo'));

    } elseif (is_single() && 'bdevs-case_study' == get_post_type()) {
        if (rtl_enable())
            $title = get_theme_mod('breadcrumb_case_study_details_rtl', __('Gallery', 'retbo'));
        else
            $title = get_theme_mod('breadcrumb_case_study_details', __('Gallery', 'retbo'));

    } elseif (is_search()) {
        $title = esc_html__('Search Results for : ', 'retbo') . get_search_query();
    } elseif (is_404()) {
        $title = esc_html__('Page not Found', 'retbo');
    } elseif (function_exists('is_woocommerce') && is_woocommerce()) {
        $title = get_theme_mod('breadcrumb_shop', __('Shop', 'retbo'));
    } elseif (is_archive()) {
        $title = get_the_archive_title();
    } else {
        $title = get_the_title();
    }

    $_id = get_the_ID();

    if (is_single() && 'product' == get_post_type()) {
        // $_id = $post->ID;
    } elseif (function_exists("is_shop") and is_shop()) {
        $_id = wc_get_page_id('shop');
    } elseif (is_home() && get_option('page_for_posts')) {
        $_id = get_option('page_for_posts');
    }

    $is_breadcrumb = function_exists('get_field') ? get_field('is_it_invisible_breadcrumb', $_id) : '';
    if (!empty($_GET['s'])) {
        $is_breadcrumb = null;
    }


    if (empty($is_breadcrumb) && $breadcrumb_show == 1) {

        $bg_img_from_page = function_exists('get_field') ? get_field('breadcrumb_background_image') : '';
        $hide_bg_img = function_exists('get_field') ? get_field('hide_breadcrumb_background_image') : '';
        $back_title = function_exists('get_field') ? get_field('breadcrumb_back_title') : '';

        // get_theme_mod
        $bg_img = get_theme_mod('breadcrumb_bg_img');


        if ($hide_bg_img) {
            $bg_img = '';
        } else {
            $bg_img = !empty($bg_img_from_page) ? $bg_img_from_page['url'] : $bg_img;
        } ?>

        <div class="breadcrumb-bg pt-150 pb-150 breadcrumb-spacing <?php print esc_attr($breadcrumb_class); ?>"
             data-background="<?php print esc_attr($bg_img); ?>">
            <div class="container">
                <div class="row">
                    <div class="col-12">
                        <div class="page-title text-center">
                            <h2 class="breadcrumb-title">
                                <?php echo wp_kses_post($title); ?>
                            </h2>
                            <div class="breadcrumb-menu">
                                <?php retbo_breadcrumb_callback(); ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <?php
    }
}

add_action('retbo_before_main_content', 'retbo_breadcrumb_func');


function retbo_breadcrumb_callback()
{
    $args = array(
        'show_browse' => false,
        'post_taxonomy' => array('product' => 'product_cat')
    );
    $breadcrumb = new Breadcrumb_Class($args);

    return $breadcrumb->trail();
}


// gru_search_form
function retbo_search_form()
{ ?>
    <!-- Modal Search -->
    <?php ob_start(); ?>
    <div class="search-wrap">
        <div class="search-inner">
            <i class="fal fa-times search-close" id="search-close"></i>
            <div class="search-cell">
                <form method="get" action="<?php print esc_url(home_url('/')); ?>">
                    <div class="search-field-holder">
                        <input type="search" name="s" class="main-search-input"
                               value="<?php print esc_attr(get_search_query()) ?>"
                               placeholder="<?php print esc_attr__('Search Entire Store...', 'retbo'); ?>">
                    </div>
                </form>
            </div>
        </div>
    </div>
    <?php return ob_get_clean(); ?>


    <?php
}

add_action('retbo_before_main_content', 'retbo_search_form');

/**
 *
 * pagination
 */
if (!function_exists('retbo_pagination')) {

    function _retbo_pagi_callback($pagination)
    {
        return $pagination;
    }

    //page navegation
    function retbo_pagination($prev, $next, $pages, $args)
    {
        global $wp_query, $wp_rewrite;
        $menu = '';
        $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

        if ($pages == '') {
            global $wp_query;
            $pages = $wp_query->max_num_pages;

            if (!$pages)
                $pages = 1;
        }

        $pagination = array(
            'base' => add_query_arg('paged', '%#%'),
            'format' => '',
            'total' => $pages,
            'current' => $current,
            'prev_text' => $prev,
            'next_text' => $next,
            'type' => 'array'
        );

        //rewrite permalinks
        if ($wp_rewrite->using_permalinks())
            $pagination['base'] = user_trailingslashit(trailingslashit(remove_query_arg('s', get_pagenum_link(1))) . 'page/%#%/', 'paged');

        if (!empty($wp_query->query_vars['s']))
            $pagination['add_args'] = array('s' => get_query_var('s'));

        $pagi = '';
        if (paginate_links($pagination) != '') {
            $paginations = paginate_links($pagination);
            $pagi .= '<ul>';
            foreach ($paginations as $key => $pg) {
                $pagi .= '<li>' . $pg . '</li>';
            }
            $pagi .= '</ul>';
        }

        print _retbo_pagi_callback($pagi);
    }
}


// rtl_enable
function rtl_enable()
{
    $my_current_lang = apply_filters('wpml_current_language', NULL);
    $rtl_enable = get_theme_mod('rtl_switch', false);
    if ($my_current_lang != 'en' && $rtl_enable) {
        return true;
    } else {
        return false;
    }
}

// theme customization
function retbo_custom()
{
    wp_enqueue_style('retbo-custom', RETBO_THEME_CSS_DIR . 'retbo-custom.css', array());
    //change breadcrumb color
    $retbo_breadcrumb_bg_color = get_theme_mod('retbo_breadcrumb_bg_color', '#222');
    if (!empty($retbo_breadcrumb_bg_color)) {
        $custom_css = '';
        $custom_css .= ".breadcrumb-spacing{ background: " . $retbo_breadcrumb_bg_color . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    // breadcrumb-spacing top
    $retbo_breadcrumb_spacing = get_theme_mod('retbo_breadcrumb_spacing', '160px');
    if (!empty($retbo_breadcrumb_spacing)) {
        $custom_css = '';
        $custom_css .= ".breadcrumb-spacing{ padding-top: " . $retbo_breadcrumb_spacing . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    // breadcrumb-spacing bottom
    $retbo_breadcrumb_bottom_spacing = get_theme_mod('retbo_breadcrumb_bottom_spacing', '160px');
    if (!empty($retbo_breadcrumb_bottom_spacing)) {
        $custom_css = '';
        $custom_css .= ".breadcrumb-spacing{ padding-bottom: " . $retbo_breadcrumb_bottom_spacing . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    // scrollup
    $retbo_scrollup_switch = get_theme_mod('retbo_scrollup_switch', false);
    if (!empty($retbo_scrollup_switch)) {
        $custom_css = '';
        $custom_css .= "#scrollUp{ display: none !important;}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    // theme color
    $retbo_color_option = get_theme_mod('retbo_color_option', '#3e976c');
    if (!empty($retbo_color_option)) {
        $custom_css = '';
        // bg
        $custom_css .= ".woocommerce-message .button.wc-forward:hover,.basic-pagination-2 ul li span:hover, .basic-pagination ul li span.current,button#place_order:hover,.single_add_to_cart_button:hover, .site-btn.brand-btn:hover,.header-mini-cart .woocommerce-mini-cart__buttons .button.checkout,.shop-cart:hover h6 span,a.button.yith-wcqv-button:hover,.slider-active button:hover,.plus-icon a:hover,.theme-bg,.bt-btn,.product-action a:hover,.product-action a:hover,.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover,.cart .site-btn.brand-btn,.sidebar-tad li a:hover, .tagcloud a:hover,.pro-list-content .product-action a:hover,.pro-list-content a.button.yith-wcqv-button:hover,.pro-list-content .product-action a:hover,.testimonial-active li.slick-active button,.testimonial-img::after,.bt-btn-white:hover,.team-social a:hover,.features__item:hover,.features__icon i,.white-video-btn:hover,.sli-five-btn,.search-five button,.shop-cart-5 h6 span,.single-categories:hover .icon,.header-left-icon a.shopping-cart-btn span{ background: " . $retbo_color_option . "}";
        // color
        $custom_css .= ".blog-title a:hover,.widget li a:hover,.widget-posts-title a:hover,.post-meta span i,.woocommerce-mini-cart .mini_cart_item:hover .cart-info .product-title,.product-zigzag h6 a:hover,.contact__icon i,.nav-link:hover,.pro-desc-tab .nav-link.active,.side-cat ul li a:hover,.side-cat ul li a:hover,.testimonial-text span,.author-desination h6,.fruit-banner-text span,.fruit-blog-text span,.fruit-blog-text h5 a:hover,.fruit-banner-text2 span,.fruit-text span.fruit-price span,.service-content h5,.service-icon i,.fruit-text span.fruit-price,.fruit-text h6 a:hover,.custom-tabs .nav-link:hover, .custom-tabs .nav-link:hover i, .custom-tabs .nav-link.active, .custom-tabs .nav-link.active i,.banner-text h3 a:hover,.product-wrapper .pro-title h6 a:hover, .product-wrapper .cart-icon a:hover,a.common-link:hover,.single-categories:hover h6 a,.common-link:hover,.header-left-icon a:hover{ color: " . $retbo_color_option . "}";
        $custom_css .= ".wp-block-quote, blockquote,.basic-pagination-2 ul li span:hover, .basic-pagination ul li span.current,button#place_order:hover,.single_add_to_cart_button:hover, .site-btn.brand-btn:hover,.contact__input-4:focus,.cart .site-btn.brand-btn,.white-video-btn:hover,.about-quote{ border-color: " . $retbo_color_option . "}";

        wp_add_inline_style('retbo-custom', $custom_css);
    }

    // retbo_custom_color_hover
    $retbo_color_hover_option = get_theme_mod('retbo_color_hover_option', '#FE6600');
    if (!empty($retbo_color_hover_option)) {
        $custom_css = '';
        $custom_css .= "{ color: " . $retbo_color_hover_option . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    // retbo_sec_color
    $retbo_sec_color_option = get_theme_mod('retbo_sec_color_option', '#FC1D53');
    if (!empty($retbo_sec_color_option)) {
        $custom_css = '';
        $custom_css .= ".{ background: " . $retbo_sec_color_option . "}";
        $custom_css .= "{ color: " . $retbo_sec_color_option . "}";
        $custom_css .= "{ border-color: " . $retbo_sec_color_option . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    // retbo_sec_hover_color
    $retbo_sec_color_hover_option = get_theme_mod('retbo_sec_color_hover_option', '#FE6600');
    if (!empty($retbo_sec_color_hover_option)) {
        $custom_css = '';
        $custom_css .= "{ color: " . $retbo_sec_color_hover_option . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }


    $retbo_top_info_color = get_theme_mod('retbo_top_info_color', '#777');
    if (!empty($retbo_top_info_color)) {
        $custom_css = '';
        $custom_css .= ".emg-text p,.promo-text span,.update-text .up-icon i,.update-text .up-content span,.update-text .up-content span{ color: " . $retbo_top_info_color . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_top_info_color_3 = get_theme_mod('retbo_top_info_color_3', '#fff');
    if (!empty($retbo_top_info_color_3)) {
        $custom_css = '';
        $custom_css .= ".header-features-three span{ color: " . $retbo_top_info_color_3 . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_top_info_color_5 = get_theme_mod('retbo_top_info_color_5', '#111');
    if (!empty($retbo_top_info_color_5)) {
        $custom_css = '';
        $custom_css .= ".emg-text-five span, .emg-text-five i,{ color: " . $retbo_top_info_color_5 . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_top_right_menu_color = get_theme_mod('retbo_top_right_menu_color', '#444');
    if (!empty($retbo_top_right_menu_color)) {
        $custom_css = '';
        $custom_css .= ".header-top-right ul li a{ color: " . $retbo_top_right_menu_color . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_mobile_menu_color = get_theme_mod('retbo_mobile_menu_color', '#101a23');
    if (!empty($retbo_mobile_menu_color)) {
        $custom_css = '';
        $custom_css .= ".side-mobile-menu ul li a{ color: " . $retbo_mobile_menu_color . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_mobile_menu_hover_color = get_theme_mod('retbo_mobile_menu_hover_color', '#3e976c');
    if (!empty($retbo_mobile_menu_hover_color)) {
        $custom_css = '';
        $custom_css .= ".side-mobile-menu ul li a:hover,.side-mobile-menu ul li ul li:hover > a{ color: " . $retbo_mobile_menu_hover_color . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_menu_color = get_theme_mod('retbo_menu_color', '#101a23');
    if (!empty($retbo_menu_color)) {
        $custom_css = '';
        $custom_css .= ".main-menu ul li a,.main-menu ul li ul.submenu li a,.side-mobile-menu ul li ul li:hover > a:before{ color: " . $retbo_menu_color . "}";
        $custom_css .= ".side-mobile-menu ul li ul li:hover > a:before{ border-color: " . $retbo_menu_color . "}";
        $custom_css .= ".side-mobile-menu ul li ul li:hover > a:before{ background: " . $retbo_menu_color . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_menu_hover_color = get_theme_mod('retbo_menu_hover_color', '#3e976c');
    if (!empty($retbo_menu_hover_color)) {
        $custom_css = '';
        $custom_css .= ".main-menu ul li:hover > a,.main-menu ul li ul.submenu li:hover > a{ color: " . $retbo_menu_hover_color . "}";

        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_menu_home_3_color = get_theme_mod('retbo_menu_home_3_color', '#fff');
    if (!empty($retbo_menu_home_3_color)) {
        $custom_css = '';
        $custom_css .= ".main-menu-3 ul li a{ color: " . $retbo_menu_home_3_color . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_menu_hover_home_3_color = get_theme_mod('retbo_menu_hover_home_3_color', '#3e976c');
    if (!empty($retbo_menu_hover_home_3_color)) {
        $custom_css = '';
        $custom_css .= ".main-menu ul li:hover > a{ color: " . $retbo_menu_hover_home_3_color . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_main_menu_font = get_theme_mod('retbo_main_menu_font', '14px');
    if (!empty($retbo_main_menu_font)) {
        $custom_css = '';
        $custom_css .= ".main-menu ul li a{ font-size: " . $retbo_main_menu_font . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_main_menu_dorpdown_font = get_theme_mod('retbo_main_menu_dorpdown_font', '13px');
    if (!empty($retbo_main_menu_dorpdown_font)) {
        $custom_css = '';
        $custom_css .= ".main-menu ul li ul.submenu li a{ font-size: " . $retbo_main_menu_dorpdown_font . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_logo_size = get_theme_mod('retbo_logo_size', '154px');
    if (!empty($retbo_logo_size)) {
        $custom_css = '';
        $custom_css .= ".logo img{ width: " . $retbo_logo_size . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }

    $retbo_mobile_logo_size = get_theme_mod('retbo_mobile_logo_size', '160px');
    if (!empty($retbo_mobile_logo_size)) {
        $custom_css = '';
        $custom_css .= ".mobile-logo img{ width: " . $retbo_mobile_logo_size . "}";
        wp_add_inline_style('retbo-custom', $custom_css);
    }
}

// retbo_color_enable
function retbo_customization_enable()
{
    $retbo_customization_enable = get_theme_mod('retbo_customization_enable', false);
    if (!empty($retbo_customization_enable)) {
        add_action('wp_enqueue_scripts', 'retbo_custom');
    }
}

retbo_customization_enable();

function retbo_shopping_cart()
{
    ob_start();
    ?>
    <div class="shopping-cart-area">
        <div class="shopping-cart-head mb-30">
            <h4><?php print esc_html__('Shopping cart','retbo'); ?></h4>
            <div class="close-shopping-cart">
                <a href="javascript:void(0);"><?php print esc_html__('close','retbo'); ?></a>
            </div>
        </div>

        <div class="header-mini-cart">
            <?php woocommerce_mini_cart(); ?>
        </div>
    </div>
    <?php
    return ob_get_clean();
}
